marktools.StemTremolo
=====================

.. abjad-lineage:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo

.. autoclass:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.tremolo_flags
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.attach
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__delattr__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__ge__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__gt__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__le__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__lt__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__repr__
   :noindex:

.. automethod:: abjad.tools.marktools.StemTremolo.StemTremolo.StemTremolo.__str__
   :noindex:
